"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ExtractTextPlugin = require("extract-text-webpack-plugin");
const os = require("os");
const parallelTypescript = {
    exclude: [/node_modules/],
    test: /\.(ts|tsx)?$/,
    use: [
        { loader: "cache-loader" },
        {
            loader: "thread-loader",
            options: {
                workers: os.cpus().length - 1,
            },
        },
        {
            loader: "ts-loader",
            options: {
                happyPackMode: true,
            },
        },
    ],
};
exports.parallelTypescript = parallelTypescript;
const typescript = {
    exclude: [/node_modules/],
    test: /\.(ts|tsx)?$/,
    use: { loader: "ts-loader" },
};
exports.typescript = typescript;
const tslint = {
    exclude: [/node_modules/],
    test: /\.(ts|tsx)?$/,
    use: "tslint-loader",
};
exports.tslint = tslint;
const sassStyles = {
    test: /\.scss$/,
    use: [
        "css-hot-loader",
        ...ExtractTextPlugin.extract({
            use: [
                "css-loader",
                "sass-loader",
            ],
        })
    ],
};
exports.sassStyles = sassStyles;
const sassGlob = {
    enforce: "pre",
    test: /\.scss$/,
    use: "import-glob",
};
exports.sassGlob = sassGlob;
const styles = {
    test: /\.css$/,
    use: [
        "css-hot-loader",
        ...ExtractTextPlugin.extract({
            use: [
                "css-loader",
            ],
        })
    ],
};
exports.styles = styles;
function images(emitFile = true) {
    return {
        test: /\.(png|jpg|gif)$/,
        use: {
            loader: "url-loader",
            options: {
                emitFile,
                limit: 4096,
                name: "img/[name].[hash].[ext]",
            },
        },
    };
}
exports.images = images;
function fonts(emitFile = true) {
    return {
        test: /\.(eot|ttf|otf|woff|woff2|svg)$/,
        use: {
            loader: "url-loader",
            options: {
                emitFile,
                limit: 4096,
                name: "fonts/[name].[hash].[ext]",
            },
        },
    };
}
exports.fonts = fonts;
const imagesNoEmit = images(false);
exports.imagesNoEmit = imagesNoEmit;
const fontsNoEmit = fonts(false);
exports.fontsNoEmit = fontsNoEmit;
const ignoreSassStyles = Object.assign(Object.assign({}, sassStyles), { use: "ignore-loader" });
exports.ignoreSassStyles = ignoreSassStyles;
const ignoreStyles = Object.assign(Object.assign({}, styles), { use: "ignore-loader" });
exports.ignoreStyles = ignoreStyles;
function getDefaultClientRules(enableParallelBuild) {
    return [
        enableParallelBuild ? parallelTypescript : typescript,
        tslint, images(), fonts(), styles, sassStyles, sassGlob,
    ];
}
exports.getDefaultClientRules = getDefaultClientRules;
function getDefaultServerRules(enableParallelBuild) {
    return [
        enableParallelBuild ? parallelTypescript : typescript,
        tslint, fontsNoEmit, imagesNoEmit, ignoreStyles, ignoreSassStyles,
    ];
}
exports.getDefaultServerRules = getDefaultServerRules;
